@@ -3,6 +3,7 @@ __author__ = 'bee'
 
 from django import forms
 from django.db.models import Q
+
 from .models import Course, Section, CourseSectionMid, Video, UserImage, UserCourse, UserAssignment, \
     UserAssignmentImage, SectionVideo, Preference, SectionAttach, UserSectionNote, UserLiveComment
 from django.forms.models import inlineformset_factory
@@ -141,6 +142,14 @@ class LivePlayLogsForm(forms.Form):
     video_id = forms.CharField(required=True, max_length=100, label='视频video_id')
     date = forms.CharField(required=True, max_length=100, label='日期', help_text='格式：2000-01-01')
 
+class UserLiveSearchForm(forms.Form):
+    user_name = forms.CharField(required=False, max_length=100, label='学生')
+
+    def __init__(self, provider_list, *args, **kwargs):
+        super(UserLiveSearchForm, self).__init__(*args, **kwargs)
+        if provider_list:
+            self.fields['provider'] = forms.ChoiceField(label='服务商', choices=provider_list, required=False)
+
 
 class UserLiveCommentForm(forms.ModelForm):
     class Meta:
