@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
 from __future__ import unicode_literals
+import datetime, pytz
 from django.core.urlresolvers import reverse
 from django.db import models, transaction
 from django.contrib.auth.models import User
@@ -11,9 +12,10 @@ from django.dispatch import receiver
 from django.db.models.signals import post_save
 from .signals import ucs_passed
 from PIL import Image, ExifTags
+from django.db.models import Q, Sum, Count
 
 # Create your models here.
-
+from .dt import get_datetime_with_scope_offset
 
 ASSIGNMENT_IMG_SIZE = (1024, 768)
 COURSE_IMG_SIZE = (800, 600)
@@ -81,7 +83,8 @@ class Course(models.Model):
     teacher = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True, verbose_name='授课老师')
     image = models.ImageField(null=True, blank=True, verbose_name='配图', upload_to='course/face')
     status = models.IntegerField(verbose_name='状态', default=0)  # 0 不显示，1 显示在列表
-    template = models.CharField(max_length=180, null=True, blank=True, verbose_name='模版')
+    template = models.CharField(max_length=180, null=True, blank=True, verbose_name='模版',
+                                help_text='在项目中custom_user下新建模版文件custom_user_course_section_list_[template].html')
 
     class Meta:
         db_table = 'bee_django_course_course'
@@ -196,7 +199,7 @@ class CourseSectionMid(models.Model):
     section = models.ForeignKey("bee_django_course.Section", verbose_name="课件")  # 课程包
     points = models.IntegerField(default=0, verbose_name='通过后获得的M币')
     order_by = models.IntegerField(default=0, verbose_name="顺序")  # 顺序
-    mins = models.IntegerField(null=True, blank=True, verbose_name='达标分钟数')  # 达标分钟数
+    mins = models.IntegerField(null=True, blank=True, verbose_name='达标分钟数')  # 达标分钟数 #可能弃用
     pre_name = models.CharField(max_length=180, verbose_name='前缀标题', null=True, blank=True)
 
     class Meta:
@@ -215,7 +218,7 @@ class Video(models.Model):
     image = models.CharField(max_length=180, null=True)  # 视频截图地址
     # ===========
     title = models.CharField(max_length=180, null=True, verbose_name='标题')  # 视频标题
-    file_name = models.CharField(max_length=180, null=True, blank=True, verbose_name='视频文件名')
+    file_name = models.CharField(max_length=180, null=True, blank=True, verbose_name='视频文件名')  # 七牛
     info = models.TextField(verbose_name='说明', null=True, blank=True)
     created_at = models.DateTimeField(auto_now_add=True)
 
@@ -358,6 +361,9 @@ class UserLive(models.Model):
     created_at = models.DateTimeField(auto_now_add=True)
     call_count = models.IntegerField(default=1)  # 回调了几次
     coin_multiple = models.IntegerField(default=0)  # 加了几倍M币
+    is_star = models.BooleanField(default=False)  # 是否标星
+    is_mentor_view = models.BooleanField(default=False)  # 助教是否观看
+    view_mentor_id = models.IntegerField(null=True)  # 观看的助教id，检查用，可删除
 
     class Meta:
         db_table = 'bee_django_course_user_live'
@@ -374,6 +380,15 @@ class UserLive(models.Model):
     def __unicode__(self):
         return ("UserLive->room_id:" + self.room_id)
 
+    # 获取开始时间的筛选条件
+    @classmethod
+    def get_start_time_filter(cls, scope=None, offset=None):
+        if scope in ["day", 'week', "month"]:
+            start_dt, end_dt = get_datetime_with_scope_offset(scope, offset)
+            return Q(start_time__range=[start_dt, end_dt])
+        else:
+            return None
+
     def get_duration_str(self, format_str=None):
         if not self.duration:
             return 0
@@ -391,6 +406,36 @@ class UserLive(models.Model):
 
         return
 
+    # 获取某[些]学生的直播分钟数，直播次数，助教观看次数
+    @classmethod
+    def get_user_live_detail(cls, user_list, scope=None, offset=None):
+        user_live_list = cls.objects.filter(user__in=user_list, status__in=[1, 2])
+        q = cls.get_start_time_filter(scope, offset)
+        if q:
+            user_live_list = user_live_list.filter(q)
+        # if start_dt:
+        #     user_live_list=user_live_list.filter(start_time__gte=start_dt)
+        # if end_dt:
+        #     user_live_list=user_live_list.filter(start_time__lt=end_dt)
+        if not user_live_list.exists():
+            return 0, 0, 0
+        # 分钟数
+        user_live_mins_res = user_live_list.aggregate(Sum("duration"))
+        if user_live_mins_res["duration__sum"]:
+            mins = user_live_mins_res["duration__sum"] / 60
+        else:
+            mins = 0
+        # 次数
+        user_live_count_res = user_live_list.aggregate(Count("id"))
+        if user_live_count_res["id__count"]:
+            count = user_live_count_res["id__count"]
+        else:
+            count = 0
+
+        mentor_view_list = user_live_list.filter(is_mentor_view=True)
+        mentor_view_count = mentor_view_list.count()
+        return mins, count, mentor_view_count
+
     # 检查学员的助教是否点评了此次录播
     def get_mentor_comments_status(self):
         user_profile = self.user.userprofile
@@ -411,6 +456,27 @@ class UserLive(models.Model):
         else:
             return False
 
+    # 助教评论了学生的几个录播数
+    @classmethod
+    def get_mentor_comment_count(cls, user, start_dt=None, end_dt=None):
+        user_live_list = cls.objects.filter(user=user, status__in=[1, 2])
+        if start_dt:
+            user_live_list = user_live_list.filter(start_time__gte=start_dt)
+        if end_dt:
+            user_live_list = user_live_list.filter(start_time__lt=end_dt)
+        mentor = User.get_assistant()
+        if not mentor:
+            return 0
+        if not user_live_list.exists():
+            return 0
+
+        user_live_list = user_live_list.filter(userlivecomment__user=mentor)
+        if start_dt:
+            user_live_list = user_live_list.filter(userlivecomment__submit_date__gte=start_dt)
+        if end_dt:
+            user_live_list = user_live_list.filter(userlivecomment__submit_date__lt=end_dt)
+        return user_live_list.count()
+
 
 class UserLiveComment(models.Model):
     user = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name='作者')
@@ -419,6 +485,7 @@ class UserLiveComment(models.Model):
     submit_date = models.DateTimeField(verbose_name='提交日期', default=timezone.now, db_index=True)
 
 
+# 课件info中富文本的图片
 class UserImage(models.Model):
     user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True)
     image = models.ImageField(verbose_name='图片', upload_to='course/%Y/%m/%d')
@@ -461,7 +528,7 @@ class UserCourseSection(models.Model):
     teacher_add_mins = models.IntegerField(verbose_name='助教增加的练习时间', null=True, blank=True)
     teacher_add_at = models.DateTimeField(verbose_name='助教操作时间', null=True, blank=True)
     send_message_at = models.DateTimeField(verbose_name='给助教发消息时间', null=True, blank=True)
-    comment = models.TextField(null=True, blank=True, verbose_name='评语')
+    comment = models.TextField(null=True, blank=True, verbose_name='评语')  # 弃用
     question_passed = models.BooleanField(default=False)
     question_passed_at = models.DateTimeField(null=True, blank=True)
 
