@@ -44,9 +44,8 @@ User = get_user_model()
 
 
 def test(request):
-    form = LivePlayLogsForm()
     # print('a', form)
-    return render(request, 'bee_django_course/live/play_logs.html', context={'form': form})
+    return render(request, 'bee_django_course/test_video.html')
 
 
 class CourseRedirectView(RedirectView):
@@ -394,7 +393,7 @@ def live_video_detail(request, user_live_id):
         live_url = get_live_str(user_live.record_video_id)
     else:
         live_url = None
-    can_view = can_view_expired_live(request.user, user_live)
+    can_view, can_record_view = can_view_expired_live(request.user, user_live)
     comments = user_live.userlivecomment_set.order_by('-submit_date')
 
     if request.method == "POST":
@@ -411,6 +410,7 @@ def live_video_detail(request, user_live_id):
 
     return render(request, 'bee_django_course/live/live_video_detail.html', context={
         "can_view": can_view,
+        "can_record_view": can_record_view,
         'user_live': user_live,
         'live_url': live_url,
         'comments': comments,
@@ -442,6 +442,50 @@ def user_live_video_detail(request, user_live_id):
     })
 
 
+def user_live_update_view(request):
+    user_live_id = request.POST.get("user_live_id")
+    mentor_id = request.POST.get("mentor_id")
+    try:
+        user_live = UserLive.objects.get(id=user_live_id)
+    except:
+        return JsonResponse(data={
+            'error': 1,
+            "msg": "参数错误"
+        })
+    if user_live.is_mentor_view == True:
+        return JsonResponse(data={
+            'error': 2,
+            "msg": "已观看"
+        })
+    try:
+        mentor = User.objects.get(id=mentor_id)
+    except:
+        return JsonResponse(data={
+            'error': 3,
+            "msg": "参数错误"
+        })
+    can_view, can_record = can_view_expired_live(mentor, user_live)
+    if not can_view or not can_record:
+        return JsonResponse(data={
+            'error': 4,
+            "msg": "超过时间或不可记录"
+        })
+    is_mentor = mentor.is_user_assistant(user_live.user)
+    if is_mentor:
+        user_live.is_mentor_view = True
+        user_live.view_mentor_id = mentor_id
+        user_live.save()
+        return JsonResponse(data={
+            'error': 0,
+            "msg": "成功"
+        })
+    else:
+        return JsonResponse(data={
+            'error': 6,
+            "msg": "不是助教"
+        })
+
+
 def edit_user_live_comment(request, user_live_comment_id):
     comment = get_object_or_404(UserLiveComment, pk=user_live_comment_id)
 
@@ -592,9 +636,11 @@ class LiveList(ListView):
             self.queryset = self.queryset.filter(user=user)
         user_name = self.request.GET.get("user_name")
         provider = self.request.GET.get("provider")
+        scope = self.request.GET.get("scope")
+        offset = self.request.GET.get("offset")
         if not provider in [0, "0", None]:
             self.queryset = self.queryset.filter(provider_name=provider)
-        if not provider in [0, "0", None]:
+        if not user_name in [0, "0", None]:
             try:
                 kwargs = {}  # 动态查询的字段
                 name_field = settings.USER_NAME_FIELD
@@ -602,6 +648,9 @@ class LiveList(ListView):
                 self.queryset = self.queryset.filter(**kwargs)
             except:
                 pass
+        if scope in ["day", 'week', "month"]:
+            q = UserLive.get_start_time_filter(scope=scope, offset=offset)
+            self.queryset = self.queryset.filter(q)
         return self.queryset
 
     def get_context_data(self, **kwargs):
@@ -621,6 +670,27 @@ class LiveList(ListView):
             else:
                 provider_list = None
             context["search_form"] = UserLiveSearchForm(provider_list, {"user_name": user_name, "provider": provider})
+        scope = self.request.GET.get("scope")
+        offset = self.request.GET.get("offset")
+        title_str = ""
+        if scope in ["day", 'week', "month"]:
+            if scope == 'day':
+                if offset == '0':
+                    title_str = '今日'
+                elif offset == '-1':
+                    print ('==')
+                    title_str = '昨日'
+            elif scope == 'week':
+                if offset == '0':
+                    title_str = '本周'
+                elif offset == '-1':
+                    title_str = '上周'
+            elif scope == 'month':
+                if offset == '0':
+                    title_str = '本月'
+                elif offset == '-1':
+                    title_str = '上月'
+            context["title_str"] = title_str
         return context
 
 
@@ -630,14 +700,13 @@ class CustomUserLivePage(ListView):
     paginate_by = 20
     queryset = None
 
-
     def _get_user(self):
         user = User.objects.get(id=self.kwargs["user_id"])
         return user
 
     def get_context_data(self, **kwargs):
         context = super(CustomUserLivePage, self).get_context_data(**kwargs)
-        user=self._get_user()
+        user = self._get_user()
         if hasattr(settings, "CC_CONFIG") and 'cc' in settings.COURSE_LIVE_PROVIDER_LIST:
             cc_userid = settings.CC_CONFIG.user_id
         else:
@@ -647,8 +716,8 @@ class CustomUserLivePage(ListView):
             gensee_room = get_room_info(user.userprofile.gensee_room_id)
         else:
             gensee_room = None
-        context['cc_userid']=cc_userid
-        context['gensee_room']=gensee_room
+        context['cc_userid'] = cc_userid
+        context['gensee_room'] = gensee_room
         return context
 
     def get_queryset(self):
@@ -762,10 +831,8 @@ class UserCourseSectionRedirectView(RedirectView):
     def _get_url(self, user_course):
         return reverse('bee_django_course:user_course_detail', kwargs={"user_course_id": user_course.id})
 
-
     def _get_no_course_url(self):
-        return reverse('bee_django_course:user_course_detail',kwargs={"user_course_id":0})
-
+        return reverse('bee_django_course:user_course_detail', kwargs={"user_course_id": 0})
 
     def get_redirect_url(self, *args, **kwargs):
         user_id = self.kwargs["user_id"]
@@ -835,7 +902,6 @@ class UserCourseDetail(ListView):
         else:
             return "bee_django_course/course/no_course.html"
 
-
     def get_queryset(self):
         user_course_id = self.kwargs["user_course_id"]
         try:
@@ -855,6 +921,37 @@ class UserCourseDetail(ListView):
 
 
 class CustomUserCourseDetail(UserCourseDetail):
+    def get_context_data(self, **kwargs):
+        context = super(CustomUserCourseDetail, self).get_context_data(**kwargs)
+        if self.user_course:
+            course = self.user_course.course
+            if not course.template in [0, "0", None]:
+                grouped_section_list = []
+                m_list = CourseSectionMid.objects.filter(course=course).order_by('order_by')
+                user_section_list = self.user_course.usercoursesection_set.filter(section__coursesectionmid__in=m_list) \
+                    .order_by('section__coursesectionmid__order_by')
+
+                ucs_dict = {}
+                default_pre_name = ''
+                for i in user_section_list:
+                    pre_name = i.get_section_mid_prename()
+                    if pre_name:
+                        grouped_section_list.append(ucs_dict)
+                        ucs_dict = {}
+                        default_pre_name = pre_name
+
+                    if ucs_dict.has_key('pre_name'):
+                        ucs_dict['ucs_list'].append(i)
+                    else:
+                        ucs_dict['pre_name'] = default_pre_name
+                        ucs_dict['ucs_list'] = [i]
+
+                grouped_section_list.append(ucs_dict)
+                print(grouped_section_list)
+                context['grouped_section_list'] = grouped_section_list
+
+        return context
+
     def get_template_names(self):
         if self.user_course:
             course = self.user_course.course
@@ -865,7 +962,7 @@ class CustomUserCourseDetail(UserCourseDetail):
             return 'bee_django_course/custom_user/custom_user_course_section_list.html'
         else:
             # 特殊模版，各项目外重写html
-            return 'bee_django_course/custom_user/custom_user_course_section_list' + course.template + '.html'
+            return 'bee_django_course/custom_user/custom_user_course_section_list_' + course.template + '.html'
 
 
 class CustomUserCourseList(ListView):
@@ -875,7 +972,6 @@ class CustomUserCourseList(ListView):
     context_object_name = 'user_course_list'
 
 
-
 # 用户课程列表的管理页面
 def manage_user_course_section_list(request, user_course_id):
     user_course = get_object_or_404(UserCourse, pk=user_course_id)
@@ -966,6 +1062,7 @@ class UserCourseSectionDetail(DetailView):
 class CustomUserCourseSectionDetail(UserCourseSectionDetail):
     template_name = 'bee_django_course/custom_user/custom_user_course_section_detail.html'
 
+
 # 用户查看作业
 def user_assignment(request, ucs_id):
     user_course_section = get_object_or_404(UserCourseSection, pk=ucs_id)
@@ -1918,6 +2015,25 @@ def delete_user_live(request, user_live_id):
         })
 
 
+class UserLiveStarUpdate(TemplateView):
+    @transaction.atomic
+    def post(self, request, *args, **kwargs):
+        user_live_id = self.request.POST.get("live_id")
+        try:
+            user_live = UserLive.objects.get(id=user_live_id)
+            user_live.is_star = not user_live.is_star
+            user_live.save()
+            return JsonResponse(data={
+                'error': 0,
+                "msg": "成功"
+            })
+        except:
+            return JsonResponse(data={
+                'error': 1,
+                "msg": "发生错误"
+            })
+
+
 def save_ucs_minus_live_mins(request):
     ucs_id = request.POST.get("ucs_id")
     mins = request.POST.get("mins")
